@@ -175,12 +175,16 @@ class FirefoxProfile(object):
         f.close()
 
     def _read_existing_userjs(self):
-        f = open(os.path.join(self.profile_dir, 'user.js'), "r")
-        tmp_usr = f.readlines()
-        f.close()
-        for usr in tmp_usr:
-            matches = re.search('user_pref\("(.*)",\s(.*)\)', usr)
-            self.default_preferences[matches.group(1)] = matches.group(2)
+        try:
+            f = open(os.path.join(self.profile_dir, 'user.js'), "r")
+            tmp_usr = f.readlines()
+            f.close()
+            for usr in tmp_usr:
+                matches = re.search('user_pref\("(.*)",\s(.*)\)', usr)
+                self.default_preferences[matches.group(1)] = matches.group(2)
+        except:
+            # The profile given hasn't had any changes made, i.e no users.js
+            pass
 
     def _install_extension(self, extension):
         tempdir = tempfile.mkdtemp()
@@ -216,6 +220,7 @@ class FirefoxProfile(object):
         if os.path.exists(ext_dir):
             shutil.rmtree(ext_dir)
         shutil.copytree(tempdir, ext_dir)
+        shutil.rmtree(tempdir)
 
     def _read_id_from_install_rdf(self, installrdfpath):
         from rdflib import Graph
